Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(295)

Unified Diff: components/autofill/core/browser/form_structure.h

Issue 2883563002: Refactor UKM interface for mojo-ification (Closed)
Patch Set: Fix uma_session_stats.cc Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/form_structure.h
diff --git a/components/autofill/core/browser/form_structure.h b/components/autofill/core/browser/form_structure.h
index 5365ec17fff1b5c34a866c87e25731f792303f7a..52fd9fbfaf47879e2e34662d01a4e86ad2deab67 100644
--- a/components/autofill/core/browser/form_structure.h
+++ b/components/autofill/core/browser/form_structure.h
@@ -39,7 +39,7 @@ class RapporServiceImpl;
}
namespace ukm {
-class UkmService;
+class UkmRecorder;
}
namespace autofill {
@@ -55,9 +55,9 @@ class FormStructure {
virtual ~FormStructure();
// Runs several heuristics against the form fields to determine their possible
// types. If |ukm_service| is specified, logs UKM for the form structure
// corresponding to |source_url_|.
- void DetermineHeuristicTypes(ukm::UkmService* ukm_service);
+ void DetermineHeuristicTypes(ukm::UkmRecorder* ukm_recorder);
// Encodes the proto |upload| request from this FormStructure.
// In some cases, a |login_form_signature| is included as part of the upload.
@@ -55,9 +55,9 @@ class FormStructure {
virtual ~FormStructure();
// Runs several heuristics against the form fields to determine their possible
- // types. If |ukm_service| is specified, logs UKM for the form structure
+ // types. If |ukm_recorder| is specified, logs UKM for the form structure
// corresponding to |source_url_|.

Powered by Google App Engine
This is Rietveld 408576698